@@ -70,7 +70,7 @@ void cfkfs_SP(
     // Save Z_SP for all observations:
     double *Z_SP = malloc(sizeof(double) * (m * d * n));
     // Save the total number of observations at every t:
-    double *d_t = malloc(sizeof(double) * n);
+    int *d_t = malloc(sizeof(int) * n);
 
     // SEQUENTIAL PROCESSING DEFINED VARIABLES:
 
@@ -461,7 +461,7 @@ void cfkfs_SP(
                 // Compute Kt = Pt %*% t(Zt[SP,,i * incZt]) %*% (1/Ft)
 
 #ifdef DEBUGME
-                Rprintf("\n New Ft: %f \n", Ft);
+                Rprintf("\n New Ft: %f \n", tmp_scalar);
 #endif
 
                 // Inv Ft:
